@@ -1,4 +1,6 @@
 """Allow users to use values directly."""
 from oblivious.oblivious import\
     native, sodium,\
-    scalar, rand, base, mul, add, sub
+    scalar, rand, inv,\
+    pnt, base,\
+    mul, add, sub
